searchData={"items":[{"type":"module","title":"Orion","doc":"Orion is a Dynamic Distributed Profiler. It allows you to profile any function\nin a beam cluster and get back an histogram representing the profile of the\nfunction calls across the whole cluster. Live, with low overhead, making it\nsuitable to run in production. It uses Erlang dynamic tracing under the hood.\n\nIt is meant to be used as a library in part of your existing application.\n\nIf you run your application non clustered, you will be able to trace the node\nyou connect to.\n\nIf your applications are connected via Distributed Erlang, then you will get\na histogram of every call on every node, aggregated.\n\n![screenshot](https://github.com/LivewareProblems/Orion/raw/main/screenshot.png)","ref":"Orion.html"},{"type":"module","title":"Non Goals - Orion","doc":"- Be useable in any BEAM language. This may happen in the future but for now we\n  depend on dog_sketch which is in elixir\n- Making it easy to run the UI locally and connect remotely to a cluster. This\n  may come in the future or in a paid extension. If you are interested, [contact\n  me on the Elixir Forum](https://elixirforum.com/u/dianaolympos/summary). In\n  the meantime, you can use the `mix dev` local development setup as a starting\n  point to do your own. Orion totally work remotely connected with erlang\n  distribution, so as long as you can connect to your cluster (and deactivate\n  the `:self_profile` option in your endpont), it should just work.\n- Session handling, in particular personal auth, and more. This may come in the\n  future or in a paid extension. If you are interested, [contact me on the\n  Elixir Forum](https://elixirforum.com/u/dianaolympos/summary). Refreshes clean\n  up the UI.","ref":"Orion.html#module-non-goals"},{"type":"module","title":"Installation - Orion","doc":"To start using Orion, you will need three steps:\n\n1. Add the `orion` dependency\n2. Configure LiveView\n3. Add UI access","ref":"Orion.html#module-installation"},{"type":"module","title":"1. Add the `orion` dependency - Orion","doc":"Add the following to your `mix.exs` and run `mix deps.get`:\n\n```elixir\ndef deps do\n  [\n    {:orion, \"~> 1.0\"}\n  ]\nend\n```","ref":"Orion.html#module-1-add-the-orion-dependency"},{"type":"module","title":"2. Configure LiveView - Orion","doc":"The Orion UI is built on top of LiveView. If LiveView is already installed in\nyour app, feel free to skip this section.\n\nIf you plan to use LiveView in your application in the future, we recommend you\nto follow [the official installation\ninstructions](https://hexdocs.pm/phoenix_live_view/installation.html). This\nguide only covers the minimum steps necessary for the Orion UI itself to run.\n\nFirst, update your endpoint's configuration to include a signing salt. You can\ngenerate a signing salt by running `mix phx.gen.secret 32` (note Phoenix v1.5+\napps already have this configuration):\n\n```elixir\n# config/config.exs\nconfig :my_app, MyAppWeb.Endpoint,\n  live_view: [signing_salt: \"SECRET_SALT\"]\n```\n\nThen add the `Phoenix.LiveView.Socket` declaration to your endpoint:\n\n```elixir\nsocket \"/live\", Phoenix.LiveView.Socket\n```\n\nAnd you are good to go!","ref":"Orion.html#module-2-configure-liveview"},{"type":"module","title":"3. Add Orion UI access for development-only usage - Orion","doc":"Once installed, update your router's configuration to forward requests to an\nOrionWeb with a unique `name` of your choosing:\n\n```elixir\n# lib/my_app_web/router.ex\nuse MyAppWeb, :router\nimport OrionWeb.Router\n...\nif Mix.env() == :dev do\n  scope \"/\" do\n    pipe_through [:browser]\n    live_orion \"/orion\"\n  end\nend\n```\n\nThis is all. Run `mix phx.server` and access the \"/orion\" to start profiling.","ref":"Orion.html#module-3-add-orion-ui-access-for-development-only-usage"},{"type":"module","title":"Extra: Add Orion access on all environments (including production) - Orion","doc":"If you want to use the Orion UI in production, you should put it behind some\nauthentication and allow only admins to access it.\n\nIf you have an authentication layer already for admins, `live_orion` accept an\n`:on_mount` option, to specify the hooks to validate your authentication, as\ndescribed in the [official phoenix guide about\nsecurity](https://hexdocs.pm/phoenix_live_view/security-model.html#mounting-considerations)\n\nIf your application does not have an admins-only section yet, you can use\n`Plug.BasicAuth` to set up some basic authentication as long as you are also\nusing SSL (which you should anyway):\n\n```elixir\n# lib/my_app_web/router.ex\nuse MyAppWeb, :router\nimport OrionWeb.Router\n...\npipeline :admins_only do\n  plug :admin_basic_auth\nend\nscope \"/\" do\n  pipe_through [:browser, :admins_only]\n    live_orion \"/orion\"\nend\ndefp admin_basic_auth(conn, _opts) do\n  username = System.fetch_env!(\"AUTH_USERNAME\")\n  password = System.fetch_env!(\"AUTH_PASSWORD\")\n  Plug.BasicAuth.basic_auth(conn, username: username, password: password)\nend\n```\n\nIf you are running your application behind a proxy or a webserver, you also have\nto make sure they are configured for allowing WebSocket upgrades. For example,\n[here is an\narticle](https://web.archive.org/web/20171104012240/https://dennisreimann.de/articles/phoenix-nginx-config.html)\non how to configure Nginx with Phoenix and WebSockets.\n\nFinally, you will also want to configure your `config/prod.exs` and use your\ndomain name under the `check_origin` configuration:\n\n```elixir\n    check_origin: [\"//myapp.com\"]\n```\n\nThen you should be good to go!","ref":"Orion.html#module-extra-add-orion-access-on-all-environments-including-production"},{"type":"module","title":"Orion.MatchSpec","doc":"","ref":"Orion.MatchSpec.html"},{"type":"function","title":"Orion.MatchSpec.from_phxlv_session/1","doc":"","ref":"Orion.MatchSpec.html#from_phxlv_session/1"},{"type":"function","title":"Orion.MatchSpec.mfa/1","doc":"","ref":"Orion.MatchSpec.html#mfa/1"},{"type":"type","title":"Orion.MatchSpec.t/0","doc":"","ref":"Orion.MatchSpec.html#t:t/0"},{"type":"function","title":"Orion.MatchSpec.to_phxlv_session/1","doc":"","ref":"Orion.MatchSpec.html#to_phxlv_session/1"},{"type":"module","title":"Orion.MatchSpecStore","doc":"","ref":"Orion.MatchSpecStore.html"},{"type":"function","title":"Orion.MatchSpecStore.from_phxlv_to_ms_options/1","doc":"","ref":"Orion.MatchSpecStore.html#from_phxlv_to_ms_options/1"},{"type":"function","title":"Orion.MatchSpecStore.get/1","doc":"","ref":"Orion.MatchSpecStore.html#get/1"},{"type":"type","title":"Orion.MatchSpecStore.key/0","doc":"","ref":"Orion.MatchSpecStore.html#t:key/0"},{"type":"type","title":"Orion.MatchSpecStore.ms_options/0","doc":"","ref":"Orion.MatchSpecStore.html#t:ms_options/0"},{"type":"function","title":"Orion.MatchSpecStore.ms_options_to_phxlv_session/1","doc":"","ref":"Orion.MatchSpecStore.html#ms_options_to_phxlv_session/1"},{"type":"function","title":"Orion.MatchSpecStore.new/3","doc":"","ref":"Orion.MatchSpecStore.html#new/3"},{"type":"type","title":"Orion.MatchSpecStore.session/0","doc":"","ref":"Orion.MatchSpecStore.html#t:session/0"},{"type":"function","title":"Orion.MatchSpecStore.string_to_boolean/1","doc":"","ref":"Orion.MatchSpecStore.html#string_to_boolean/1"},{"type":"function","title":"Orion.MatchSpecStore.string_to_state/1","doc":"","ref":"Orion.MatchSpecStore.html#string_to_state/1"},{"type":"module","title":"Orion.SessionPubsub","doc":"A Registry based pubsub that works per session. Allows all the LV of a session to talk together.","ref":"Orion.SessionPubsub.html"},{"type":"function","title":"Orion.SessionPubsub.dispatch/2","doc":"","ref":"Orion.SessionPubsub.html#dispatch/2"},{"type":"function","title":"Orion.SessionPubsub.register/2","doc":"","ref":"Orion.SessionPubsub.html#register/2"},{"type":"module","title":"OrionWeb.Components","doc":"","ref":"OrionWeb.Components.html"},{"type":"function","title":"OrionWeb.Components.error/1","doc":"Generates a generic error message.","ref":"OrionWeb.Components.html#error/1"},{"type":"function","title":"Slots - OrionWeb.Components.error/1","doc":"* `inner_block` (required)","ref":"OrionWeb.Components.html#error/1-slots"},{"type":"function","title":"OrionWeb.Components.input/1","doc":"Renders an input with label and error messages.\nA `%Phoenix.HTML.Form{}` and field name may be passed to the input\nto build input names and error messages, or all the attributes and\nerrors may be passed explicitly.","ref":"OrionWeb.Components.html#input/1"},{"type":"function","title":"Examples - OrionWeb.Components.input/1","doc":"<.input field={@form[:email]} type=\"email\" />\n    <.input name=\"my-input\" errors={[\"oh no!\"]} />","ref":"OrionWeb.Components.html#input/1-examples"},{"type":"function","title":"Attributes - OrionWeb.Components.input/1","doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:any`)\n* `label` (`:string`) - Defaults to `nil`.\n* `value` (`:any`)\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `errors` (`:list`) - Defaults to `[]`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs.\n* `prompt` (`:string`) - the prompt for select inputs. Defaults to `nil`.\n* `options` (`:list`) - the options to pass to Phoenix.HTML.Form.options_for_select/2.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"autocomplete\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"OrionWeb.Components.html#input/1-attributes"},{"type":"function","title":"Slots - OrionWeb.Components.input/1","doc":"* `inner_block`","ref":"OrionWeb.Components.html#input/1-slots"},{"type":"function","title":"OrionWeb.Components.label/1","doc":"Renders a label.","ref":"OrionWeb.Components.html#label/1"},{"type":"function","title":"Attributes - OrionWeb.Components.label/1","doc":"* `for` (`:string`) - Defaults to `nil`.","ref":"OrionWeb.Components.html#label/1-attributes"},{"type":"function","title":"Slots - OrionWeb.Components.label/1","doc":"* `inner_block` (required)","ref":"OrionWeb.Components.html#label/1-slots"},{"type":"function","title":"OrionWeb.Components.translate_error/1","doc":"","ref":"OrionWeb.Components.html#translate_error/1"},{"type":"function","title":"OrionWeb.Components.translate_errors/2","doc":"Translates the errors for a field from a keyword list of errors.","ref":"OrionWeb.Components.html#translate_errors/2"},{"type":"module","title":"OrionWeb.PageLive","doc":"This is the central LiveView for the Orion UI.\n\nIt handles the form to pass a matchspec, store then in the Orion.MatchSpecDB,\nthen start the chart as needed by passing the ref to that line to the chart liveview\nin the sessions.\n\nIt also handles pause/start\n\nTODO: change this, to allow multiple users at once","ref":"OrionWeb.PageLive.html"},{"type":"function","title":"OrionWeb.PageLive.pause_state_text/1","doc":"","ref":"OrionWeb.PageLive.html#pause_state_text/1"},{"type":"module","title":"OrionWeb.Router","doc":"Provides LiveView routing for Orion.","ref":"OrionWeb.Router.html"},{"type":"macro","title":"OrionWeb.Router.live_orion/2","doc":"Define an Orion route.\n\nIt expects the `path` Orion will be mounted at and a set of options\n\nAll the Orion Pages will be under a live_session.","ref":"OrionWeb.Router.html#live_orion/2"},{"type":"macro","title":"Options - OrionWeb.Router.live_orion/2","doc":"* `:live_socket_path` - Configures the socket path. it must match the\n    `socket \"/live\", Phoenix.LiveView.Socket` in your endpoint.\n\n  * `:csp_nonce_assign_key` - an assign key to find the CSP nonce value used\n    for assets. Supports either `atom()` or a map of type `%{optional(:img) =>\n    atom(), optional(:script) => atom(), optional(:style) => atom()}`\n\n  * `:on_mount` - Pass a list of `on_mount` hooks to live_session, like if you\n    want to validate authentication with `:on_mount`. See [the\n    phoenix_liveview\n    docs](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.Router.html#live_session/3)\n\n  * `:live` - Configure options to inject into the Orion route\n\n  * `:self_profile` - Configure if the tracing is applied to the node running Orion itself, default to true\n\n  * `:fake_data` - Configure if the tracing form allow you to run with fake data, default to false","ref":"OrionWeb.Router.html#live_orion/2-options"},{"type":"macro","title":"Examples - OrionWeb.Router.live_orion/2","doc":"defmodule MyAppWeb.Router do\n      use Phoenix.Router\n      import OrionWeb.Router\n      scope \"/\", MyAppWeb do\n        pipe_through [:browser]\n        live_orion \"/orion\",\n          on_mount: {MyAppWeb.SomeHook, :admin}\n      end\n    end","ref":"OrionWeb.Router.html#live_orion/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}